@@ -110,13 +110,14 @@ class KARPClient(object):
         return asyncio.ensure_future(self._read())
 
     async def request(
-        self, route: str, request_data: str, timeout=None
-    ) -> Response:
+        self, route: str, request_data: str, timeout=None, response=True,
+    ) -> Optional[Response]:
         """
         Request something
         :param route:
         :param request_data:
         :param timeout: Timeout, None for infinite, raises TimeoutError on failure
+        :param response: wait for a response
         :return:
         """
         req = Request.create(route, request_data)
@@ -126,6 +127,9 @@ class KARPClient(object):
 
         await self.writer.drain()
 
+        if not response:
+            return
+
         try:
             response = await self._requests[req.request_id].process(
                 timeout=timeout
